Skip to contents

Get the dimensions of an HDF5 dataset or sparse matrix

Usage

Dims(x)

Arguments

x

An HDF5 dataset or sparse matrix

Value

A vector with the dimensions of the dataset or sparse matrix. For sparse matrices, if no dimensions are found in either the “dims” or “shape” attribute, returns c(NA_integer_, NA_integer_)

See also