Skip to contents

Check to see if a dataset, group, or attribute exists in an HDF5 file, group, or dataset

Usage

AttrExists(x, name)

Exists(x, name)

Arguments

x

An HDF5 file or group; for AttrExists, may also be a dataset

name

Name of dataset, group, or attribute to test for

Value

TRUE if name exists in x, otherwise FALSE