Extended implementation of SeuratDisk for Seurat v5. Provides interfaces for HDF5-based single-cell file formats including h5Seurat and AnnData (h5ad) with enhanced support for Seurat v5 Assay5 and spatial data.
Package options
srtdisk uses the following options to control behavior, users can configure
these with options:
SeuratDisk.dtypes.logical_to_intWhen writing logical vectors, coerce to integer types to ensure compatibility across languages (see
BoolToIntfor more details)SeuratDisk.dtypes.dataframe_as_groupWhen writing data.frames, always write out as a group regardless of factor presence
SeuratDisk.chunking.MARGINDefault direction for chunking datasets; choose from:
- largest
Chunk along the largest dimension of a dataset
- smallest
Chunk along the smallest dimension
- first
Chunk along the first dimension
- last
Chunk along the last dimension
SeuratDisk.dimreducs.allglobalTreat all DimReducs as global, regardless of actual global status
SeuratDisk.compression.levelGzip compression level for HDF5 dataset writes (0-9). Level 0 means no compression, level 4 (default) is a good balance of speed vs size. Only applies to newly created datasets, not to data copied via
obj_copy_from.
Author
Maintainer: Miana Z zzeng4@nd.edu
Authors:
Paul Hoffman phoffman@nygenome.org (ORCID)
Rahul Satija rsatija@nygenome.org (ORCID)