Check to see if a dataset, group, or attribute exists in an HDF5 file, group, or dataset
Source:R/h5info.R
H5Exists.RdCheck to see if a dataset, group, or attribute exists in an HDF5 file, group, or dataset
R/h5info.R
H5Exists.RdCheck to see if a dataset, group, or attribute exists in an HDF5 file, group, or dataset