Create an HDF5 object path
Arguments
- ...
one or more R objects, to be converted to character vectors.
- collapse
an optional character string to separate the results. Not
NA_character_. Whencollapseis a string, the result is always a string (characterof length 1).