Determine if a matrix is empty or not. A matrix is considered empty if it satisfies one of the following conditions:
The dimensions of the matrix are 0-by-0 (
all(dim(x) == 0))The dimensions of the matrix are 1-by-1 (
all(dim(x) == 1)) and the sole vlaue isNA
These two situations correspond to matrices generated with either
new('matrix') or matrix()