Version-specific loom-file loading functions
Usage
LoadLoom0.1(
file,
assay = NULL,
cells = "col_atts/CellID",
features = "row_attrs/Gene",
normalized = NULL,
scaled = NULL,
filter = c("cells", "features", "all", "none"),
verbose = TRUE
)
LoadLoom3.0(
file,
assay = NULL,
cells = "col_attrs/CellID",
features = "row_attrs/Gene",
normalized = NULL,
scaled = NULL,
filter = c("cells", "features", "all", "none"),
verbose = TRUE
)Arguments
- assay
Name of assay to store expression data as. If
NULL, will search for an HDF5 attribute namedSEURAT_ASSAYor dataset at/attrs/SEURAT_ASSAYfor the assay name. Defaults to"RNA"if not found.- cells
Name of dataset in
/col_attrscontaining cell/sample names. If not found, uses column indices as cell names.- features
Name of dataset in
/row_attrscontaining feature/gene names. If not found, uses row indices as feature names.- normalized
Name of layer in
/layersto load as normalized expression data; special value"/matrix"loads the main matrix as normalized data instead of counts- scaled
Name of layer in
/layersto load as scaled data- filter
Logical; if
TRUE, keep only cells and features marked as valid using/col_attrs/Validand/row_attrs/Validattributes- verbose
Logical; if
TRUE(default), show progress updates