Attempts to validate a string to use as a Seurat key. Valid keys must match
the regular expression ^[[:alnum:]]+_$; if key fails this
regular expression, an attempt to modify it to said key will be made by
removing all non-alphanumeric characters, collapsing the resulting vector,
and appending “_”. If this stil fails, a random string of lowercase
characters will be generated, followed by “_”, to be used as the key