Skip to contents

A class for connections to loom files

A class for connections to loom files

Format

An R6Class object

See also

Super classes

hdf5r::H5RefClass -> hdf5r::H5File -> srtdisk::scdisk -> loom

Methods

Inherited methods


Method add_attribute()

Add an attribute

Usage

loom$add_attribute(x, name, type = c("global", "row", "col"))

Arguments

x

Object to add as an attribute

name

Name to store attribute as

type

Type of attribute to add


Method add_graph()

Add a graph

Usage

loom$add_graph(x, name, type = c("col", "row"), verbose = TRUE)

Arguments

x

...

name

...

type

...

verbose

...


Method add_layer()

Add a layer to this loom file

Usage

loom$add_layer(x, name, transpose = TRUE, verbose = TRUE)

Arguments

x

An object to save as a layer

name

Name to store layer as

transpose

...

verbose

...

Returns

Invisibly returns NULL


Method version()

Get version information

Usage

loom$version()

Returns

A numeric_version object with the loom specification version information


Method timestamp()

Add a timestamp to a dataset or group as an HDF5 attribute

Usage

loom$timestamp(name = NULL)

Arguments

name

Name of dataset or group to add timestamp to; if NULL, timestamps the file as a whole

Returns

Invisibly returns the object


Method last.modified()

Retrieve a timestamp from a dataset or group

Usage

loom$last.modified(name = NULL, locale = FALSE)

Arguments

name

Name of dataset or group to retrieve timestamp from; if NULL, retrieves timestamp from at the file-level

locale

Change the timestamp of to the timezone of the locale

Returns

A character with the timestamp