Read the cell embeddings (obsm) from an H5AD file and return them as a named list of matrices. Each entry corresponds to a dimensional reduction (e.g., PCA, UMAP, t-SNE).
Read the cell embeddings (obsm) from an H5AD file and return them as a named list of matrices. Each entry corresponds to a dimensional reduction (e.g., PCA, UMAP, t-SNE).