A disk-based object for single-cell analysis
A disk-based object for single-cell analysis
Format
An R6Class object
Super classes
hdf5r::H5RefClass -> hdf5r::H5File -> scdisk
Methods
Inherited methods
hdf5r::H5RefClass$close()hdf5r::H5RefClass$dec_ref()hdf5r::H5RefClass$get_file_id()hdf5r::H5RefClass$get_obj_type()hdf5r::H5RefClass$get_ref()hdf5r::H5RefClass$inc_ref()hdf5r::H5RefClass$methods()hdf5r::H5File$attr_delete()hdf5r::H5File$attr_delete_by_idx()hdf5r::H5File$attr_delete_by_name()hdf5r::H5File$attr_exists()hdf5r::H5File$attr_exists_by_name()hdf5r::H5File$attr_get_number()hdf5r::H5File$attr_info_by_idx()hdf5r::H5File$attr_info_by_name()hdf5r::H5File$attr_name_by_idx()hdf5r::H5File$attr_open()hdf5r::H5File$attr_open_by_idx()hdf5r::H5File$attr_open_by_name()hdf5r::H5File$attr_rename()hdf5r::H5File$attr_rename_by_name()hdf5r::H5File$close_all()hdf5r::H5File$commit()hdf5r::H5File$create_attr()hdf5r::H5File$create_attr_by_name()hdf5r::H5File$create_dataset()hdf5r::H5File$create_group()hdf5r::H5File$create_reference()hdf5r::H5File$exists()hdf5r::H5File$file_info()hdf5r::H5File$flush()hdf5r::H5File$get_filename()hdf5r::H5File$get_filesize()hdf5r::H5File$get_intent()hdf5r::H5File$get_obj_count()hdf5r::H5File$get_obj_ids()hdf5r::H5File$get_obj_name()hdf5r::H5File$group_info()hdf5r::H5File$group_info_by_idx()hdf5r::H5File$group_info_by_name()hdf5r::H5File$link()hdf5r::H5File$link_copy_from()hdf5r::H5File$link_copy_to()hdf5r::H5File$link_create_external()hdf5r::H5File$link_create_hard()hdf5r::H5File$link_create_soft()hdf5r::H5File$link_delete()hdf5r::H5File$link_delete_by_idx()hdf5r::H5File$link_exists()hdf5r::H5File$link_info()hdf5r::H5File$link_info_by_idx()hdf5r::H5File$link_move_from()hdf5r::H5File$link_move_to()hdf5r::H5File$link_name_by_idx()hdf5r::H5File$link_value()hdf5r::H5File$link_value_by_idx()hdf5r::H5File$ls()hdf5r::H5File$mount()hdf5r::H5File$obj_copy_from()hdf5r::H5File$obj_copy_to()hdf5r::H5File$obj_info()hdf5r::H5File$obj_info_by_idx()hdf5r::H5File$obj_info_by_name()hdf5r::H5File$open()hdf5r::H5File$open_by_idx()hdf5r::H5File$path_valid()hdf5r::H5File$print()hdf5r::H5File$unmount()
Method new()
Create a new scdisk object
Arguments
filenameName of on-disk file to connect to
modeHow to open the file, choose from:
- a
Create new or open existing file, allow read and write
- r
Open existing file, allow read only
- r+
Open existing file, allow read and write
- w
Create new file (deleting any existing one), allow read and write
- w-, x
Create new file (error if exists), allow read and write
validateValidate the file upon connection
...Extra arguments passed to validation routine
Method chunk.points()
Generate chunk points for a dataset
Usage
scdisk$chunk.points(
dataset,
MARGIN = getOption(x = "SeuratDisk.chunking.MARGIN", default = "largest"),
csize = NULL
)Method timestamp()
Add a timestamp to a dataset or group as an HDF5 attribute
Usage
scdisk$timestamp(
name = NULL,
attr = "ts",
tz = "UTC",
format = TSFormats(type = "R")
)Arguments
nameName of dataset or group to add timestamp to; if
NULL, timestamps the file as a wholeattrName of attribute to store timestamp ass
tz, formatSee
Timestamp
Method last.modified()
Retrieve a timestamp from a dataset or group
Usage
scdisk$last.modified(
name = NULL,
attr = "ts",
locale = TRUE,
tz = "UTC",
format = TSFormats(type = "R")
)Arguments
nameName of dataset or group to retrieve timestamp from; if
NULL, retrieves timestamp from at the file-levelattrName of attribute to retrieve timestamp from
localeChange the timestamp of to the timezone of the locale
tz, formatSee
Timestamp